// Java Script functions for the 7KG966 device
// ===========================================
//
// "defines"
// ---------
// Page handling instructions: 
// Changing of the HTML pages (add, remove etc) has to be adapted here.
// The values has to be in accordance to the enum defined in HttpUtil.h.
// For more information grep for "Page handling instructions"
var PAGE_AC_MEASUREMENT             = 1;
var PAGE_CONF_OPEN_CFG              = 2;
var PAGE_ACTIVATION                 = 3;
var PAGE_ANALOG_OUTPUTS             = 4;
var PAGE_BINARY_OUTPUTS             = 5;
var PAGE_CALIBRATION_AC             = 6;
var PAGE_CALIBRATION_DC             = 7;
var PAGE_COMM_ETHERNET              = 8;
var PAGE_COMM_SERIAL                = 9;
var PAGE_DEVICE                     = 10;
var PAGE_LEDS                       = 11;
var PAGE_MEASURAND_LIMITS           = 12;
var PAGE_TIME_SYNC                  = 13;
var PAGE_INFO_DEVICE_INFO           = 14;
var PAGE_INFO_ERROR_LOG             = 15;
var PAGE_INFO_OP_LOG                = 16;
var PAGE_MAINT_CALIBRATION          = 17;
var PAGE_MAINT_DIAG_MODBUS          = 18;
var PAGE_MAINT_ERROR_LOG            = 19;
var PAGE_MAINT_FW_UPLOAD            = 20;
var PAGE_MAINT_OP_LOG               = 21;
var PAGE_MAINT_SYSTEM               = 22;
var PAGE_MAINT_PASSWORD             = 23;
var PAGE_MAINT_UPLOAD_CONFIRM       = 24;
var PAGE_MODE_CFG                   = 25;
var PAGE_MODE_INFO                  = 26;
var PAGE_MODE_MAINT                 = 27;
var PAGE_MODE_VIEW                  = 28;
var PAGE_VIEW_AC_OPERATIONAL_VALUES = 29;
var PAGE_VIEW_AC_POWER              = 30;
var PAGE_VIEW_DC_ANALOG_OUTPUTS     = 31;
var PAGE_VIEW_BINARY_OUTPUTS        = 32;
var PAGE_VIEW_MEASURAND_LIMITS      = 33;
var PAGE_CONF_ACCESS_TIMER          = 34;
var PAGE_UNKNOWN                    = 35;

// Functions
// ---------

//*****************************************************************************
//* maintDateTime                                                 
//* Description : Handles displaying the system date/time or the PC date/time.
//* Parameters  : sendsrc describes the origination of the function call. 
//*               It can be the "SET" button (sendsrc = 1) or the "GET" button
//*               (sendsrc = 2).
//* Return value: None.
//*****************************************************************************
function maintDateTime(sendsrc)
{
   var date = 0;
   var month = 0;

   document.forms.MaintDateTime.SendSrc.value = sendsrc;

   if (sendsrc == 2) { // get PC date/time
      date = new Date();
      document.forms.MaintDateTime.Day.value = date.getDate();
      
      // For a short moment the browser values are visible in the HTML page. 
      // JavaScript numbers the month beginning with 0 for january without 
      // leading zero.
      // After getting the date/time from the browser request it will be set 
      // as system time and displayed again after reloading the page. 
      // The month will be corrected here to avoid different displaying. 
      month = date.getMonth();
      if (month < 10) 
         document.forms.MaintDateTime.Month.value = "0" + (date.getMonth() + 1);
      else 
         document.forms.MaintDateTime.Month.value = date.getMonth() + 1; 

      document.forms.MaintDateTime.Year.value = date.getYear();
      document.forms.MaintDateTime.Hours.value = date.getHours();
      document.forms.MaintDateTime.Minutes.value = date.getMinutes();
   }
   else {
      var pwd = document.forms.MaintDateTime.Password.value;
      var chg = document.forms.MaintDateTime.Challenge.value;
      var pwd_md5 = hex_md5(pwd);
      var str = pwd_md5 + chg;
      var hash = hex_md5(str);
      document.forms.MaintDateTime.Password.value = hash;  
      document.forms.MaintDateTime.Challenge.value = chg;
   }

   document.MaintDateTime.submit();
}


//*****************************************************************************
//* mntPwd2md5                                                
//* Description : Concatenates md5 of password and challenge and builds 
//*               the MD5 hash from the concatenation.
//* Parameters  : None.
//* Return value: None.
//*****************************************************************************
function mntPwd2md5()
{
   var pwd = document.forms.MaintPassword.Password.value;
   var chg = document.forms.MaintPassword.Challenge.value;
   var pwd_md5 = hex_md5(pwd);
   var str = pwd_md5 + chg;
   var hash = hex_md5(str);
   document.forms.MaintPassword.Password.value = hash;  
   document.forms.MaintPassword.Challenge.value = chg;
   document.forms.MaintPassword.submit();
}

//*****************************************************************************
//* updatePage
//* Description : Updates the page given in pageId.
//* Parameters  : sendSrc describes the origination of the function call. 
//*               It can be a change of the selectbox content (= 1) or pressing 
//*               the send button (= 2). sendsrc is given to the form for 
//*               further handling.                                                             
//*               pageId descibes the HTML page which has to be updated. 
//* Return value: None.
//*****************************************************************************
function updatePage(sendSrc, pageId)
{
   switch (pageId) {
      case PAGE_MEASURAND_LIMITS:
         document.forms.MeasurandLimits.SendSrc.value = sendSrc;
         document.MeasurandLimits.submit();
         break;
      case PAGE_ANALOG_OUTPUTS:
         document.forms.ConfDcAnalogOutputs.SendSrc.value = sendSrc;
         document.ConfDcAnalogOutputs.submit();
         break;
      case PAGE_MAINT_CALIBRATION:
         document.forms.ConfMaintenance.SendSrc.value = sendSrc;
         document.ConfMaintenance.submit();
         break;
      default:
         document.forms.ConfDcAnalogOutputs.SendSrc.value = sendSrc;
         document.ConfDcAnalogOutputs.submit();
         break;
   }
}


